@@ -4,7 +4,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: controls.cpp,v 1.41 2007/04/11 17:20:09 mbarbon Exp $
+// RCS-ID:      $Id: controls.cpp,v 1.42 2007/04/28 18:39:41 mbarbon Exp $
 // Copyright:   (c) 2000-2007 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -189,7 +189,7 @@ wxListItemAttr* wxPliListCtrl::OnGetItemAttr( long item ) const
                                                      G_SCALAR, "l", item );
         wxListItemAttr* val = (wxListItemAttr*)
             wxPli_sv_2_object( aTHX_ ret, "Wx::ListItemAttr" );
-        val = new wxListItemAttr( *val );
+        val = val ? new wxListItemAttr( *val ) : NULL;
         SvREFCNT_dec( ret );
         return val;
     }
